pub fn init_extrinsics(k: &Matrix3<f64>, h: &Matrix3<f64>) -> Option<Extrinsics>
Recover the pose for one view from intrinsics k and homography h.
k
h
Returns None if k is singular or the homography is degenerate.
None